@@ -4,7 +4,7 @@
 #' @param x File names
 #' @param cache_path path to cached files
 #' @param force (logical) Should files be force deleted? Default: \code{FALSE}
-#' @references \url{http://upwell.pfeg.noaa.gov/erddap/index.html}
+#' @references \url{https://upwell.pfeg.noaa.gov/erddap/index.html}
 #' @author Scott Chamberlain <myrmecocystus@@gmail.com>
 #' @seealso \code{\link{cache_list}}, \code{\link{cache_details}}
 #' @examples \dontrun{
@@ -36,12 +36,14 @@ cache_delete.tabledap <- function(x, cache_path = "~/.rerddap", force = FALSE) {
 }
 
 #' @export
-cache_delete.griddap_nc <- function(x, cache_path = "~/.rerddap", force = FALSE) {
+cache_delete.griddap_nc <- function(x, cache_path = "~/.rerddap",
+                                    force = FALSE) {
   cdel(basename(attr(x, "path")), cache_path, force)
 }
 
 #' @export
-cache_delete.griddap_csv <- function(x, cache_path = "~/.rerddap", force = FALSE) {
+cache_delete.griddap_csv <- function(x, cache_path = "~/.rerddap",
+                                     force = FALSE) {
   cdel(basename(attr(x, "path")), cache_path, force)
 }
 
@@ -51,7 +53,8 @@ cache_delete.list <- function(x, cache_path = "~/.rerddap", force = FALSE) {
 }
 
 #' @export
-cache_delete.character <- function(x, cache_path = "~/.rerddap", force = FALSE) {
+cache_delete.character <- function(x, cache_path = "~/.rerddap",
+                                   force = FALSE) {
   cdel(x, cache_path, force)
 }
 
@@ -59,7 +62,8 @@ cache_delete.character <- function(x, cache_path = "~/.rerddap", force = FALSE)
 cdel <- function(files, cache_path = "~/.rerddap", force = FALSE) {
   files <- file.path(cache_path, files)
   if (!all(file.exists(files))) {
-    stop("These files don't exist or can't be found: \n", strwrap(files[!file.exists(files)], indent = 5), call. = FALSE)
+    stop("These files don't exist or can't be found: \n",
+         strwrap(files[!file.exists(files)], indent = 5), call. = FALSE)
   }
   unlink(files, force = force)
 }
