@@ -9,7 +9,8 @@ griddap <- function(x, ..., fields = 'all', stride = 1, fmt = "nc",
   calls <- names(sapply(match.call(), deparse))[-1]
   calls_vec <- "ncdf" %in% calls
   if (any(calls_vec)) {
-    stop("The parameter ncdf has been removed. We use ncdf4 package now internally",
+    stop(
+      "The parameter ncdf has been removed. We use ncdf4 package now internally",
          call. = FALSE)
   }
 
@@ -26,20 +27,30 @@ griddap <- function(x, ..., fields = 'all', stride = 1, fmt = "nc",
   dims <- dimvars(x)
   store <- toggle_store(fmt, store)
   if (all(var == "none")) {
-    args <- paste0(sapply(dims, function(y) parse_args(x, y, stride, dimargs, wname = TRUE)), collapse = ",")
+    args <- paste0(sapply(dims, function(y) {
+      parse_args(x, y, stride, dimargs, wname = TRUE)
+    }), collapse = ",")
   } else {
     pargs <- sapply(dims, function(y) parse_args(x, y, stride, dimargs))
-    args <- paste0(lapply(var, function(y) paste0(y, paste0(pargs, collapse = ""))), collapse = ",")
+    args <- paste0(lapply(var, function(y) {
+      paste0(y, paste0(pargs, collapse = ""))
+    }), collapse = ",")
   }
   fmt <- match.arg(fmt, c("nc", "csv"))
   resp <- erd_up_GET(url = sprintf("%sgriddap/%s.%s", url, d, fmt), dset = d,
                      args = args, store = store, fmt = fmt, callopts)
   loc <- if (store$store == "disk") resp else "memory"
   outclasses <- switch(fmt,
-                       nc = c("griddap_nc", "nc"),
+                       nc = c("griddap_nc", "nc", "data.frame"),
                        csv = c("griddap_csv", "csv", "data.frame"))
   read <- toggle_read(read, store)
-  structure(read_all(resp, fmt, read), class = outclasses, datasetid = d, path = loc)
+  structure(
+    read_all(resp, fmt, read),
+    class = outclasses,
+    datasetid = d,
+    path = loc,
+    url = url_build(sprintf("%sgriddap/%s.%s", url, d, fmt), args)
+  )
 }
 
 toggle_read <- function(x, store) {
@@ -63,7 +74,7 @@ toggle_store <- function(fmt, store) {
 }
 
 #' @export
-print.griddap_csv <- function(x, ..., n = 10){
+print.griddap_csv <- function(x, ...) {
   finfo <- file_info(attr(x, "path"))
   cat(sprintf("<ERDDAP griddap> %s", attr(x, "datasetid")), sep = "\n")
   path <- attr(x, "path")
@@ -74,11 +85,11 @@ print.griddap_csv <- function(x, ..., n = 10){
     cat(sprintf("   File size:    [%s mb]", finfo$size), sep = "\n")
   }
   cat(sprintf("   Dimensions:   [%s X %s]\n", NROW(x), NCOL(x)), sep = "\n")
-  trunc_mat(x, n = n)
+  print(tibble::as_data_frame(x))
 }
 
 #' @export
-print.griddap_nc <- function(x, ..., n = 10){
+print.griddap_nc <- function(x, ...) {
   finfo <- file_info(attr(x, "path"))
   cat(sprintf("<ERDDAP griddap> %s", attr(x, "datasetid")), sep = "\n")
   path <- attr(x, "path")
@@ -92,7 +103,7 @@ print.griddap_nc <- function(x, ..., n = 10){
   cat(sprintf("   Dim names: %s", paste0(names(x$summary$dim), collapse = ", ")), sep = "\n")
   cat(sprintf("   Variable names: %s", paste0(unname(sapply(x$summary$var, "[[", "longname")), collapse = ", ")), sep = "\n")
   cat(sprintf("   data.frame (rows/columns):   [%s X %s]", dim(x$data)[1], dim(x$data)[2]), sep = "\n\n")
-  trunc_mat(x$data, n = n)
+  print(tibble::as_data_frame(x$data))
 }
 
 field_handler <- function(x, y){
@@ -193,14 +204,6 @@ fix_dims <- function(dimargs, .info) {
   dimargs
 }
 
-# which_min <- function(x) {
-#   if (is(x, "character")) {
-#     grep(min(tmp), tmp)
-#   } else {
-#     which.min(x)
-#   }
-# }
-
 parse_args <- function(.info, dim, s, dimargs, wname = FALSE){
   tmp <- if (dim %in% names(dimargs)) {
     dimargs[[dim]]
